# Pigweed

Pigweed is an open source collection of embedded-targeted libraries–or as we
like to call them, modules. These modules are building blocks and infrastructure
that enable faster and more reliable development on small-footprint MMU-less
32-bit microcontrollers like the STMicroelectronics STM32L452 or the Nordic
nRF52832.

For more information please see our website: https://pigweed.dev/.

## Links

<!-- TODO(b/256680603) Remove query string from issue tracker link. -->

- [Documentation](https://pigweed.dev/)
- [Source Code](https://cs.pigweed.dev/pigweed)
- [Code Reviews](https://pigweed-review.googlesource.com)
- [Mailing List](https://groups.google.com/forum/#!forum/pigweed)
- [Chat Room](https://discord.gg/M9NSeTA)
- [Issue Tracker](https://issues.pigweed.dev/issues?q=status:open)

